@@ -3,15 +3,17 @@ use strict;
 use warnings;
 use Exporter 'import';
 our @EXPORT = qw( args );
+use Carp ();
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
 sub args {
     my $opts = shift;
+    
     if (ref $opts ne 'HASH') {
         die 'args method require hashref.';
     }
-
+    
     my $caller_args;
     if (scalar(@_) >= 2) {
         $caller_args = $_[1];
@@ -27,16 +29,11 @@ sub args {
         die 'It is only hashref to be able to treat args method.';
     }
 
-    my $args;
-    for my $key (keys %$opts) {
-        if (exists $caller_args->{$key}) {
-            $args->{$key} = $caller_args->{$key};
-        }
-        if ($opts->{$key} && not defined $args->{$key}) {
-            die "$key required!";
-        }
-    }
-    $args;
+    map {($opts->{$_} && not defined $caller_args->{$_}) ? Carp::confess "Mandatory parameter '$_' missing.": () } keys %$opts;
+
+    map {(not defined $opts->{$_}) ? Carp::confess "not listed in the following parameter: $_.": () } keys %$caller_args;
+
+    $caller_args;
 }
 
 1;
@@ -74,7 +71,7 @@ Sub::Args - Simple check/get arguments.
       }
   );
   
-  # got +{name => 'nekokak', age => 32}
+  # nick parameter don't defined for args method.
   foo(
       {
           name => 'nekokak',
@@ -98,8 +95,14 @@ This module makes your module more readable, and writable =p
 
 Atsushi Kobayashi E<lt>nekokak _at_ gmail _dot_ comE<gt>
 
+=head1 CONTRIBUTORS
+
+hirobanex : Hiroyuki Akabane
+
 =head1 SEE ALSO
 
+L<Params::Validate>
+
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
